mechmat.properties.elastic\_deformation package
===============================================

Module contents
---------------

.. automodule:: mechmat.properties.elastic_deformation
    :members:
    :undoc-members:
    :show-inheritance:
